<?php
/**
 * AJAX endpoint to get updated cart notification
 */

// 处理可能传递的会话ID
if (isset($_POST['PHPSESSID']) && !empty($_POST['PHPSESSID'])) {
    session_id($_POST['PHPSESSID']);
    error_log("get_notification.php: 使用传递的会话ID: " . $_POST['PHPSESSID']);
}

session_start();
require_once __DIR__ . '/../config/config.php';
require_once __DIR__ . '/../config/database.php';
require_once __DIR__ . '/../user/code/auth.php';
require_once __DIR__ . '/notification.php';

// 使用auth.php中的函数判断登录状态，保持一致性
$isLoggedIn = isLoggedIn();
$userId = getCurrentUserId();

// 添加调试信息
error_log("get_notification.php: isLoggedIn()返回: " . ($isLoggedIn ? 'true' : 'false'));
error_log("get_notification.php: getCurrentUserId()返回: " . ($userId ?? 'null'));
error_log("get_notification.php: SESSION数据: " . json_encode($_SESSION));

// 确保用户ID同步
if (isset($_SESSION['user_id']) && (!isset($_SESSION['member_id']) || $_SESSION['member_id'] != $_SESSION['user_id'])) {
    $_SESSION['member_id'] = $_SESSION['user_id'];
    error_log("get_notification.php: 已同步member_id为user_id: " . $_SESSION['user_id']);
}

// 始终直接从数据库获取最新余额
$balance = 0;
if ($isLoggedIn && $userId) {
    $balance = calculateUserBalance($userId);
    error_log("get_notification.php: 直接从数据库获取的余额: " . $balance);
}

// Get total price from POST
$totalPrice = isset($_POST['totalPrice']) ? floatval($_POST['totalPrice']) : 0;

// Return the notification HTML
$notification = getCartNotification($isLoggedIn, $balance, $totalPrice);
error_log("get_notification.php: 生成的通知内容: " . htmlspecialchars($notification));
error_log("get_notification.php: isLoggedIn=" . ($isLoggedIn ? 'true' : 'false') . 
         ", balance=" . $balance . ", totalPrice=" . $totalPrice);

echo $notification;
?> 