<?php
session_start();
include_once __DIR__ . '/../code/cart_code.php';
require_once __DIR__ . '/../config/config.php';
require_once __DIR__ . '/../config/database.php';
require_once __DIR__ . '/../user/code/auth.php';
require_once __DIR__ . '/notification.php';

// 确保Telegram变量可用
if (!isset($Telegram) && function_exists('getConfig')) {
    $Telegram = getConfig('Telegram', '');
}

// 确保下单时：
// 1. finance表中amount字段为负数 ($amountToDeduct = -1 * abs($price))
// 2. payment_status字段为1（表示已支付，因为只有余额充足才能下单）
// 这与order_ajax.php的设置保持一致

$cartData = getCartPageData();
$product_id = $cartData['product_id'];
$product = $cartData['product'];
$userId = $cartData['userId'];
$balance = $cartData['balance'];
$locationText = $cartData['locationText'];
$lineName = $cartData['lineName'];
$osBrands = $cartData['osBrands'];
$osVersions = $cartData['osVersions'];
$allOsVersionsJson = $cartData['allOsVersionsJson'];
$debugJson = $cartData['debugJson'];

// 初始化订单总价，确保这个变量在全局作用域内可用
$totalPrice = isset($product) ? floatval($product['price'] ?? 397.05) : 397.05;

// 添加中间件检查
function checkOrderRequirements($totalPrice) {
    global $product;
    
    // 检查用户是否登录
    if (!isLoggedIn()) {
        return [false, '请先登录后再继续购买'];
    }

    // 获取用户ID和余额
    $userId = getCurrentUserId();
    $balance = calculateUserBalance($userId);
    
    // 检查余额是否充足
    if ($balance < $totalPrice) {
        $shortfall = number_format($totalPrice - $balance, 2);
        return [false, "余额不足，还差 $$shortfall"];
    }
    
    return [true, ''];
}

// 执行中间件检查
list($canProceed, $message) = checkOrderRequirements($totalPrice);

// 如果检查不通过，显示错误信息
if (!$canProceed) {
    error_log("订单前置检查失败: $message");
}
?>
<!-- 新增调试代码，显示SESSION变量 -->
<?php
if (defined('DEBUG_MODE') && DEBUG_MODE) {
    error_log("Cart.php: SESSION详情: " . json_encode($_SESSION));
    error_log("Cart.php: user_id = " . ($_SESSION['user_id'] ?? 'null') . ", member_id = " . ($_SESSION['member_id'] ?? 'null'));
    
    // 直接在这里重新计算一次余额作为对比
    if ($userId) {
        $recalculatedBalance = calculateUserBalance($userId);
        error_log("Cart.php: 直接重新计算的余额为 $recalculatedBalance (与从getCartPageData获取的 $balance 对比)");
        
        // 如果余额不同，则使用直接计算的结果
        if ($recalculatedBalance != $balance) {
            error_log("Cart.php: 使用重新计算的余额 $recalculatedBalance 替换原始余额 $balance");
            $balance = $recalculatedBalance;
        }
    }
}
?>
<!DOCTYPE html>
<html lang="zh">
    <head>
        <meta charset="UTF-8">
        <meta name="viewport" content="width=device-width, initial-scale=1.0">
        <title> 购物车</title>
        <meta name="keywords" content="服务器购物车,服务器配置,主机定制,服务器订购,服务器购买流程,云服务器配置,服务器租用,增值服务,服务器参数选择">
        <meta name="description" content="通过我们的购物车系统灵活配置您的理想服务器，可自定义操作系统、带宽、IP地址数量等核心参数，并提供多种免费增值服务选项。支持月付、季付、年付多种付款方式，专业级服务器定制体验。">
        <link href="https://fonts.googleapis.com/icon?family=Material+Icons" rel="stylesheet">
        <link href="https://unpkg.com/aos@2.3.1/dist/aos.css" rel="stylesheet">
        <link href="/public/css/style.css" rel="stylesheet">
        <link rel="stylesheet" href="../public/css/cart.css">
        <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.0.0/css/all.min.css">
        <link href="/public/css/breadcrumb.css" rel="stylesheet">
        <script>
        window.allOsVersions = <?php echo $allOsVersionsJson; ?>;
        window.debugInfo = <?php echo $debugJson ?? '{}'; ?>;
        // 购物车数据 - 用于结算功能
        window.cartData = {
            productId: <?php echo $product_id ?? 0; ?>,
            userId: <?php echo isset($_SESSION['user_id']) ? $_SESSION['user_id'] : 0; ?>
        };
        window.debugMode = <?php echo defined('DEBUG_MODE') && DEBUG_MODE ? 'true' : 'false'; ?>;
        window.phpSessionId = '<?php echo session_id(); ?>';
        </script>
    </head>
    <body>
        <?php include '../public/header.php'; ?>
        <!-- Banner 区域 -->
        <?php include '../public/banner.php'; ?>
        <!--内容区块-->
        <div class="container">
            <div class="main">
                <!-- 面包屑导航 -->
                <div class="container">
                    <div class="breadcrumb">
                        <a href="/">首页</a>
                        <i class="material-icons">chevron_right</i>
                        <a href="/product">产品服务</a>
                        <i class="material-icons">chevron_right</i>
                        <span>购物车</span>
                    </div>
                </div>
                <div class="cart-container">
                    <?php
            // 直接调用auth.php中的isLoggedIn函数判断登录状态
            $isLoggedIn = isLoggedIn();
            error_log("Cart.php: isLoggedIn()返回: " . ($isLoggedIn ? 'true' : 'false'));
            error_log("Cart.php: userId值: " . ($userId ?? 'null'));
            error_log("Cart.php: SESSION: " . json_encode($_SESSION));
            
            // 使用全局变量中的价格，确保一致性
            error_log("Cart.php: 使用的totalPrice: $totalPrice");
            
            echo getCartNotification($isLoggedIn, $balance, $totalPrice);
          ?>
                    <h2 class="cart-title">我的购物车</h2> <?php if ($product_id > 0 && isset($product)): ?> <div class="cart-items">
                        <div class="cart-item">
                            <div class="server-info">
                                <h3 class="server-title"><?php echo $locationText . '高速服务器'; ?></h3>
                                <div class="server-specs">
                                    <p><i class="fas fa-hashtag"></i>编号: <span><?php echo str_pad($product['id'], 6, '0', STR_PAD_LEFT); ?></span></p>
                                    <p><i class="fas fa-microchip"></i>CPU: <span><?php echo htmlspecialchars($product['upc'] ?? '未设置'); ?></span></p>
                                    <p><i class="fas fa-memory"></i>内存: <span><?php echo htmlspecialchars($product['memory'] ?? '未设置'); ?></span></p>
                                    <p><i class="fas fa-hdd"></i>硬盘: <span><?php echo htmlspecialchars($product['disk'] ?? '未设置'); ?></span></p>
                                    <p><i class="fas fa-network-wired"></i>带宽: <span><?php echo htmlspecialchars($product['bandwidth'] ?? '未设置'); ?></span></p>
                                    <p><i class="fas fa-tachometer-alt"></i>流量: <span><?php echo htmlspecialchars($product['traffic'] ?? '不限流量'); ?></span></p>
                                    <p><i class="fas fa-shield-alt"></i>防护: <span><?php echo htmlspecialchars($product['defense'] ?? '可选'); ?></span></p>
                                    <p><i class="fas fa-globe"></i>IP数量: <span><?php echo htmlspecialchars($product['ip_count'] ?? '1'); ?></span></p>
                                    <p><i class="fas fa-map-marker-alt"></i>线路: <span><?php echo htmlspecialchars($lineName ?? 'CN2线路'); ?></span></p>
                                    <p><i class="fas fa-server"></i>机房: <span><?php echo htmlspecialchars($locationText ?? '高速'); ?></span></p>
                                </div>
                            </div>
                            <div class="server-pricing">
                                <div class="price-plan">
                                    <label>
                                        <input type="radio" name="price-plan" value="monthly" data-price="397.05" checked> 月付 </label>
                                    <span class="price">$397.05/月</span>
                                </div>
                                <div class="price-plan">
                                    <label>
                                        <input type="radio" name="price-plan" value="quarterly" data-price="<?php echo 397.05 * 3 * 0.95; ?>"> 季付 </label>
                                    <span class="price"> $<?php echo number_format(397.05 * 3 * 0.95, 2); ?>/季 <span class="discount-tag">95折</span>
                                    </span>
                                </div>
                                <div class="price-plan">
                                    <label><input type="radio" name="price-plan" value="half-year" data-price="<?php echo 397.05 * 6 * 0.98; ?>"> 半年付</label>
                                    <span class="price">$<?php echo number_format(397.05 * 6 * 0.98, 2); ?>/半年 <span class="discount-tag">98折</span></span>
                                </div>
                                <div class="price-plan">
                                    <label><input type="radio" name="price-plan" value="yearly" data-price="<?php echo 397.05 * 12 * 0.9; ?>"> 年付</label>
                                    <span class="price">$<?php echo number_format(397.05 * 12 * 0.9, 2); ?>/年 <span class="discount-tag">9折</span></span>
                                </div>
                                <div class="config-item flex-row">
                                    <div class="flex-group quantity-group">
                                        <div class="config-label">数量:</div>
                                        <div class="config-value">
                                            <div class="quantity-control">
                                                <button type="button" class="decrease">-</button>
                                                <input type="number" value="1" min="1" class="quantity-input">
                                                <button type="button" class="increase">+</button>
                                            </div>
                                        </div>
                                    </div>
                                    <div class="flex-group auto-renew-group">
                                        <div class="config-label">自动续费:</div>
                                        <div class="config-value">
                                            <label class="switch-wrapper">
                                                <input type="checkbox" id="auto-renew">
                                                <span class="switch-slider"></span>
                                            </label>
                                        </div>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </div> <?php else: ?> <div class="empty-cart">系统 <i class="material-icons">shopping_cart</i>
                        <p>购物车是空的</p>
                        <a href="/product" class="btn btn-primary">去选购</a>
                    </div> <?php endif; ?> <?php if ($product_id > 0 && isset($product)): ?> <div class="section-divider"></div>
                    <!-- 服务器配置部分 -->
                    <div class="config-section">
                        <h3><i class="fas fa-server"></i> 服务器配置</h3>
                        <div class="config-item">
                            <div class="config-label">主机名:</div>
                            <div class="config-value">
                                <input type="text" class="form-control" value="<?php echo htmlspecialchars(($product['code'] ?? 'My') . date('YmdHis')); ?>" placeholder="请输入主机名">
                            </div>
                        </div>
                        <div class="config-item">
                            <div class="config-label">控制台密码:</div>
                            <div class="config-value">
                                <div class="password-input-container">
                                    <input type="password" value="<?php echo generateRandomPassword(); ?>" class="form-control" id="console-password" readonly>
                                    <button type="button" class="toggle-password" onclick="togglePassword()">
                                        <i class="fas fa-eye"></i>
                                    </button>
                                    <button type="button" class="refresh-password" onclick="refreshPassword()">
                                        <i class="fas fa-sync-alt"></i>
                                    </button>
                                </div>
                            </div>
                        </div>
                        <div class="config-item">
                            <div class="config-label">操作系统:</div>
                            <div class="config-value">
                                <div class="os-selects-row">
                                    <div class="os-brand-container">
                                        <select class="form-control os-brand-select" id="os-brand"> <?php foreach ($osBrands as $id => $name): ?> <option value="<?php echo $id; ?>"><?php echo htmlspecialchars($name); ?></option> <?php endforeach; ?> </select>
                                    </div>
                                    <div class="os-version-container">
                                        <select class="form-control os-version-select" id="os-version"> <?php 
                      // 默认显示第一个品牌的版本
                      $firstBrandId = array_key_first($osBrands);
                      if (isset($osVersions[$firstBrandId])):
                        foreach ($osVersions[$firstBrandId] as $version):
                      ?> <option value="<?php echo $version['id']; ?>"><?php echo htmlspecialchars($version['name']); ?></option> <?php 
                        endforeach;
                      endif;
                      ?> </select>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </div>
                    <div class="section-divider"></div> <?php if ($product_id > 0 && isset($product)): ?> <div class="cart-bottom-summary">
                        <div class="left-summary">
                            <span>数量：</span><strong id="bottom-quantity">1</strong> 台 <span>总价：</span><span class="price-highlight" id="bottom-total-price">$<?php echo number_format($totalPrice, 2); ?></span>
                        </div>
                        <div class="cart-buttons">
                            <?php if ($isLoggedIn && $balance >= 1 && $balance < $totalPrice): ?>
                            <!-- 情况3: 余额>=1美元但不足支付订单 - 显示申请测试按钮 -->
                            <a href="<?php echo htmlspecialchars($Telegram); ?>" target="_blank" class="apply-test-btn">
                                <i class="fas fa-headset"></i> 申请测试
                            </a>
                            <?php endif; ?>
                            
                            <?php if (!$isLoggedIn): ?>
                            <!-- 情况1: 未登录状态 - 两个按钮都不可点击 -->
                            <button class="checkout-btn-large disabled" disabled>
                                <i class="fas fa-shopping-cart"></i> 请先登录
                            </button>
                            <?php elseif ($balance < 1): ?>
                            <!-- 情况2: 余额<1美元 - 无法申请测试和结算 -->
                            <button class="checkout-btn-large disabled" disabled>
                                <i class="fas fa-shopping-cart"></i> 充值1美元即可申请测试
                            </button>
                            <?php elseif ($balance < $totalPrice): ?>
                            <!-- 情况3: 余额>=1美元但不足支付订单 -->
                            <button class="checkout-btn-large disabled" disabled onclick="alert('您的余额不足，请先充值或申请测试')">
                                <i class="fas fa-shopping-cart"></i> 余额不足，可先测试或充值
                            </button>
                            <?php else: ?>
                            <!-- 情况4: 余额足够支付订单 - 只显示结算按钮 -->
                            <button class="checkout-btn-large" onclick="validateAndSubmit()">
                                <i class="fas fa-shopping-cart"></i> 结算
                            </button>
                            <?php endif; ?>
                        </div>
                    </div> <?php endif; ?> <?php endif; ?>
                </div>
            </div>
        </div> <?php include '../public/footer.php'; ?> <?php include '../public/kf.php'; ?> <script src="/public/js/js.js"></script>
        <script src="../public/js/cart.js"></script>
    </body>
</html>
