<?php
/**
 * Cart notification component
 * Displays different messages based on user login status and balance
 */

function getCartNotification($isLoggedIn, $balance, $totalPrice) {
    $notificationClass = 'cart-notification';
    $icon = '<i class="fas fa-info-circle"></i>';
    
    // 添加调试日志
    error_log("getCartNotification: isLoggedIn=" . ($isLoggedIn ? 'true' : 'false') . ", balance=$balance, totalPrice=$totalPrice");
    
    if (!$isLoggedIn) {
        // 情况1: 未登录
        $notificationClass .= ' warning';
        $icon = '<i class="fas fa-exclamation-triangle"></i>';
        return "<div class=\"{$notificationClass}\">{$icon} 请先登录后再继续购买。<a href=\"/user/login.php\" class=\"login-link\">立即登录</a></div>";
    }
    
    if ($balance < 1) {
        // 情况2: 余额小于1美元
        $notificationClass .= ' info';
        return "<div class=\"{$notificationClass}\">{$icon} 您的余额不足，只需充值 $1 即可申请测试使用。<a href=\"/user/recharge.php\" class=\"recharge-link\">立即充值</a></div>";
    }
    
    if ($balance < $totalPrice) {
        // 情况3: 余额大于等于1美元但不足以支付订单
        $notificationClass .= ' warning';
        $shortfall = number_format($totalPrice - $balance, 2);
        $formattedBalance = number_format($balance, 2);
        return "<div class=\"{$notificationClass}\">{$icon} 当前余额 $" . $formattedBalance . "，还差 $" . $shortfall . "。您可以申请测试或<a href=\"/user/recharge.php\" class=\"recharge-link\">立即充值</a></div>";
    }
    
    // 情况4: 余额足够支付订单
    $notificationClass .= ' success';
    $icon = '<i class="fas fa-check-circle"></i>';
    $formattedBalance = number_format($balance, 2);
    return "<div class=\"{$notificationClass}\">{$icon} 余额 $" . $formattedBalance . "，可以直接下单。</div>";
}
?>
