<?php
/**
 * 原生站群页面数据处理文件
 */
// 确保文件被包含而非直接访问
defined('INCLUDED_FROM_VIEW') or define('INCLUDED_FROM_VIEW', true);
// 引入网站配置
require_once dirname(__FILE__) . '/../public/config.php';
/**
 * 获取预定义的原生站群产品数据
 * 
 * @param bool $debug 是否开启调试模式
 * @return array 预定义的产品数据数组
 */
function getNativeClusterProducts($debug = false) {
    // 获取数据库连接
    $db = getDbConnection();
    $result = [];
    
    try {
        // 构建SQL查询语句 - 获取所有原生站群产品
        $query = "SELECT p.*, 
                    CONCAT('8', LPAD(p.id, 4, '0')) as number,
                    a.name as location,
                    l.name as line,
                    CONCAT(a.name, '专区') as region
                 FROM products p 
                 LEFT JOIN area a ON p.region_id = a.id
                 LEFT JOIN line l ON p.line_id = l.id
                 WHERE FIND_IN_SET(23, p.tags) 
                 AND FIND_IN_SET(19, p.tags)
                 AND p.status = 1 
                 ORDER BY p.price ASC";
        
        $stmt = $db->query($query);
        $products = $stmt->fetchAll(PDO::FETCH_ASSOC);
    
        // 如果开启调试模式，打印查询结果
    if ($debug) {
        echo '<pre style="background:#f5f5f5; padding:15px; margin:15px; border:1px solid #ddd; display:none;">';
            echo '<h3>原生站群产品数据</h3>';
        print_r($products);
        echo '</pre>';
    }
    
    return $products;
    } catch (PDOException $e) {
        // 错误处理
        if ($debug) {
            echo "Debug: Error occurred - " . $e->getMessage() . "\n";
        }
        error_log("获取原生站群产品数据错误: " . $e->getMessage());
        return [];
    }
}

/**
 * 获取标签名称
 *
 * @param PDO $db 数据库连接
 * @param array $tagIds 标签ID数组
 * @return array 标签名称数组
 */
function getTagNames($db, $tagIds) {
    $tagNames = [];
    
    if (empty($tagIds)) {
        return $tagNames;
    }
    
    try {
        $placeholders = implode(',', array_fill(0, count($tagIds), '?'));
        $query = "SELECT id, name FROM tags WHERE id IN ($placeholders)";
        
        $stmt = $db->prepare($query);
        
        // 绑定参数
        foreach ($tagIds as $index => $id) {
            $stmt->bindValue($index + 1, $id);
        }
        
        $stmt->execute();
        
        while ($tag = $stmt->fetch()) {
            $tagNames[$tag['id']] = $tag['name'];
        }
    } catch (PDOException $e) {
        error_log("获取标签名称错误: " . $e->getMessage());
    }
    
    return $tagNames;
} 
