<?php
// 确保没有任何输出破坏JSON响应
ob_start();

// 添加订单调试日志功能
function orderLog($message) {
    $logFile = __DIR__ . '/../logs/order_debug.log';
    $timestamp = date('Y-m-d H:i:s');
    $logMessage = "[$timestamp] $message\n";
    file_put_contents($logFile, $logMessage, FILE_APPEND);
}

// 记录订单处理开始
orderLog("=================== 新的订单请求 ===================");
orderLog("请求方法: " . $_SERVER['REQUEST_METHOD']);
orderLog("请求数据: " . json_encode($_POST));
orderLog("请求IP: " . $_SERVER['REMOTE_ADDR']);
orderLog("User Agent: " . $_SERVER['HTTP_USER_AGENT']);

// 启动会话 - 如果传入了会话ID则使用它
if (isset($_POST['PHPSESSID'])) {
    $sessionId = $_POST['PHPSESSID'];
    orderLog("使用提供的会话ID: $sessionId");
    session_id($sessionId);
}
session_start();

// 记录会话信息
orderLog("会话ID: " . session_id());
orderLog("会话数据: " . json_encode($_SESSION));

// 引入必要的文件
try {
    orderLog("开始引入必要文件");
    // 修正路径为相对于web根目录的绝对路径，避免open_basedir限制
    require_once __DIR__ . '/../config/config.php';
    require_once __DIR__ . '/../config/database.php';
    require_once __DIR__ . '/../user/code/auth.php';
    orderLog("文件引入完成");
} catch (Exception $e) {
    orderLog("文件引入错误: " . $e->getMessage());
    // 清除任何可能的输出
    ob_clean();
    // 设置响应头
    header('Content-Type: application/json');
    echo json_encode(['success' => false, 'message' => '系统配置错误: ' . $e->getMessage()]);
    exit;
}

// 添加调试信息
error_log("订单处理开始 - order_ajax.php - 会话ID: " . session_id());
error_log("当前会话内容: " . print_r($_SESSION, true));

// 检查AJAX请求
if ($_SERVER['REQUEST_METHOD'] === 'POST' && isset($_POST['action']) && $_POST['action'] === 'create_order') {
    // 清除之前的任何输出
    ob_clean();
    
    // 设置响应头
    header('Content-Type: application/json');
    
    orderLog("收到创建订单请求: " . json_encode($_POST));
    error_log("收到创建订单请求: " . json_encode($_POST));
    
    // 连接数据库
    try {
        // 直接使用配置文件中定义的常量
        orderLog("尝试连接数据库: " . DB_HOST);
        error_log("尝试使用常量直接连接数据库：" . DB_HOST);
        $dsn = "mysql:host=" . DB_HOST . ";dbname=" . DB_NAME . ";charset=" . DB_CHARSET;
        $options = [
            PDO::ATTR_ERRMODE => PDO::ERRMODE_EXCEPTION,
            PDO::ATTR_DEFAULT_FETCH_MODE => PDO::FETCH_ASSOC,
            PDO::ATTR_EMULATE_PREPARES => false,
        ];
        
        $conn = new PDO($dsn, DB_USER, DB_PASSWORD, $options);
        orderLog("数据库连接成功");
        error_log("数据库连接成功");
    } catch (PDOException $e) {
        $errorMsg = "数据库连接失败：" . $e->getMessage();
        orderLog($errorMsg);
        error_log($errorMsg);
        echo json_encode(['success' => false, 'message' => '数据库连接失败: ' . $e->getMessage()]);
        exit;
    }
    
    // 获取当前登录用户ID
    $userId = isset($_POST['user_id']) && !empty($_POST['user_id']) ? intval($_POST['user_id']) : 0;
    orderLog("从POST获取的用户ID: $userId");
    
    // 如果POST中没有用户ID，尝试从会话中获取
    if (!$userId && function_exists('getCurrentUserId')) {
        $userId = getCurrentUserId();
        orderLog("从getCurrentUserId()获取到用户ID: " . $userId);
        error_log("从getCurrentUserId()获取到用户ID: " . $userId);
    }
    
    // 如果还是没有，尝试直接从会话中获取
    if (!$userId && isset($_SESSION['user_id'])) {
        $userId = intval($_SESSION['user_id']);
        orderLog("从SESSION获取到用户ID: " . $userId);
        error_log("从SESSION获取到用户ID: " . $userId);
    }
    
    // 如果所有方法都失败，尝试从GET/POST中获取userId参数
    if (!$userId && isset($_REQUEST['userId'])) {
        $userId = intval($_REQUEST['userId']);
        orderLog("从请求参数获取用户ID: " . $userId);
        error_log("从请求参数获取用户ID: " . $userId);
    }
    
    // 如果仍然获取不到用户ID，获取当前URL中可能包含的userId
    if (!$userId) {
        // 模拟检查查询字符串中是否有userId
        $queryString = $_SERVER['QUERY_STRING'] ?? '';
        if (preg_match('/userId=(\d+)/', $queryString, $matches)) {
            $userId = intval($matches[1]);
            orderLog("从URL查询字符串获取用户ID: " . $userId);
            error_log("从URL查询字符串获取用户ID: " . $userId);
        }
    }
    
    // 网站前台共享的已登录用户ID
    if (!$userId && isset($GLOBALS['loggedInUserId'])) {
        $userId = intval($GLOBALS['loggedInUserId']);
        orderLog("从全局变量获取用户ID: " . $userId);
        error_log("从全局变量获取用户ID: " . $userId);
    }
    
    // 如果用户未登录，返回错误
    if (!$userId) {
        orderLog("未能获取有效的用户ID，请求中的user_id: " . (isset($_POST['user_id']) ? $_POST['user_id'] : '未设置'));
        error_log("未能获取有效的用户ID，请求中的user_id: " . (isset($_POST['user_id']) ? $_POST['user_id'] : '未设置'));
        
        $errorMsg = "用户未登录，请先登录";
        orderLog($errorMsg);
        echo json_encode(['success' => false, 'message' => $errorMsg]);
        exit;
    }
    
    // 调试当前会话状态
    orderLog("当前会话状态: " . json_encode($_SESSION));
    error_log("当前会话状态: " . print_r($_SESSION, true));
    
    // 获取提交的数据
    $hostname = isset($_POST['hostname']) ? trim($_POST['hostname']) : '';
    $panel_password = isset($_POST['panel_password']) ? trim($_POST['panel_password']) : '';
    $price = isset($_POST['price']) ? floatval($_POST['price']) : 0;
    $next_payment_date = isset($_POST['next_payment_date']) ? trim($_POST['next_payment_date']) : date('Y-m-d', strtotime('+1 month'));
    $product_type = isset($_POST['product_type']) ? trim($_POST['product_type']) : '高速服务器';
    $ip_address = isset($_POST['ip_address']) ? trim($_POST['ip_address']) : '';
    $os_type = isset($_POST['os_type']) ? trim($_POST['os_type']) : '';
    $currency = isset($_POST['currency']) ? trim($_POST['currency']) : 'USD';
    $quantity = isset($_POST['quantity']) ? intval($_POST['quantity']) : 1;
    $product_id = isset($_POST['product_id']) ? trim($_POST['product_id']) : '';
    $status = isset($_POST['status']) ? intval($_POST['status']) : 1;
    
    // 记录关键订单数据
    orderLog("订单数据: 主机名=$hostname, 价格=$price, 产品ID=$product_id, 会员ID=$userId");
    
    // 验证必填字段
    if (empty($hostname) || empty($panel_password)) {
        $errorMsg = "主机名和密码不能为空";
        orderLog($errorMsg);
        echo json_encode(['success' => false, 'message' => $errorMsg]);
        exit;
    }
    
    // 写入orders表
    try {
        // 记录SQL调试信息
        orderLog("准备写入订单数据：用户ID: $userId, 主机名: $hostname, 价格: $price");
        error_log("准备写入订单数据：用户ID: $userId, 主机名: $hostname, 价格: $price");
        
        // 使用与数据库表结构一致的大小写
        $sql = "INSERT INTO orders (MemberID, hostname, panel_password, price, next_payment_date, product_type, ip_address, os_type, currency, quantity, product_id, status) 
                VALUES (:member_id, :hostname, :panel_password, :price, :next_payment_date, :product_type, :ip_address, :os_type, :currency, :quantity, :product_id, :status)";
        
        $stmt = $conn->prepare($sql);
        
        // 绑定参数
        $stmt->bindParam(':member_id', $userId, PDO::PARAM_INT);
        $stmt->bindParam(':hostname', $hostname, PDO::PARAM_STR);
        $stmt->bindParam(':panel_password', $panel_password, PDO::PARAM_STR);
        $stmt->bindParam(':price', $price, PDO::PARAM_STR);
        $stmt->bindParam(':next_payment_date', $next_payment_date, PDO::PARAM_STR);
        $stmt->bindParam(':product_type', $product_type, PDO::PARAM_STR);
        $stmt->bindParam(':ip_address', $ip_address, PDO::PARAM_STR);
        $stmt->bindParam(':os_type', $os_type, PDO::PARAM_STR);
        $stmt->bindParam(':currency', $currency, PDO::PARAM_STR);
        $stmt->bindParam(':quantity', $quantity, PDO::PARAM_INT);
        $stmt->bindParam(':product_id', $product_id, PDO::PARAM_STR);
        $stmt->bindParam(':status', $status, PDO::PARAM_INT);
        
        // 记录将要执行的SQL（用于调试）
        $debugSql = $sql;
        foreach([':member_id' => $userId, ':hostname' => $hostname, ':panel_password' => $panel_password, 
                 ':price' => $price, ':next_payment_date' => $next_payment_date, ':product_type' => $product_type, 
                 ':ip_address' => $ip_address, ':os_type' => $os_type, ':currency' => $currency, 
                 ':quantity' => $quantity, ':product_id' => $product_id, ':status' => $status] as $key => $value) {
            $debugSql = str_replace($key, "'$value'", $debugSql);
        }
        orderLog("即将执行SQL: $debugSql");
        error_log("即将执行SQL: $debugSql");
        
        // 执行SQL
        $stmt->execute();
        
        // 获取新创建的订单ID
        $order_id = $conn->lastInsertId();
        
        // 记录调试信息
        orderLog("已成功创建新订单，ID: $order_id, 用户ID: $userId, 价格: $price, 产品类型: $product_type");
        error_log("已成功创建新订单，ID: $order_id, 用户ID: $userId, 价格: $price, 产品类型: $product_type");
        
        // 添加余额检查和扣除逻辑
        try {
            // 1. 检查用户当前余额
            $currentBalance = calculateUserBalance($userId);
            orderLog("当前用户余额: $currentBalance, 订单价格: $price");
            error_log("当前用户余额: $currentBalance, 订单价格: $price");
            
            // 2. 检查余额是否足够
            if ($currentBalance < $price) {
                // 如果余额不足，删除刚创建的订单
                $deleteOrderSql = "DELETE FROM orders WHERE id = :order_id";
                $deleteStmt = $conn->prepare($deleteOrderSql);
                $deleteStmt->bindParam(':order_id', $order_id, PDO::PARAM_INT);
                $deleteStmt->execute();
                
                orderLog("余额不足，已删除订单 $order_id，当前余额: $currentBalance, 需要: $price");
                error_log("余额不足，已删除订单 $order_id，当前余额: $currentBalance, 需要: $price");
                
                // 返回错误信息
                echo json_encode([
                    'success' => false, 
                    'message' => '余额不足，无法完成下单。当前余额: $' . number_format($currentBalance, 2) . '，订单金额: $' . number_format($price, 2)
                ]);
                exit;
            }
            
            // 3. 如果余额足够，向finance表添加扣除记录
            $amountToDeduct = -1 * abs($price); // 确保是负数
            $description = "购买" . $product_type . " - 订单号 #" . $order_id;
            $now = date('Y-m-d H:i:s');
            
            $financeSql = "INSERT INTO finance (type, amount, member_id, description, payment_status, operator_id, created_at, updated_at) 
                           VALUES (:type, :amount, :member_id, :description, :payment_status, :operator_id, :created_at, :updated_at)";
            
            $financeStmt = $conn->prepare($financeSql);
            $financeStmt->bindValue(':type', 3, PDO::PARAM_INT); // 3表示系统订单
            $financeStmt->bindParam(':amount', $amountToDeduct, PDO::PARAM_STR);
            $financeStmt->bindParam(':member_id', $userId, PDO::PARAM_INT);
            $financeStmt->bindParam(':description', $description, PDO::PARAM_STR);
            $financeStmt->bindValue(':payment_status', 1, PDO::PARAM_INT); // 1表示已支付
            $financeStmt->bindValue(':operator_id', 0, PDO::PARAM_INT); // 0表示系统操作
            $financeStmt->bindParam(':created_at', $now, PDO::PARAM_STR);
            $financeStmt->bindParam(':updated_at', $now, PDO::PARAM_STR);
            
            $financeStmt->execute();
            
            $newBalance = $currentBalance + $amountToDeduct;
            orderLog("已成功扣除余额: $amountToDeduct, 原余额: $currentBalance, 新余额: $newBalance");
            error_log("已成功扣除余额: $amountToDeduct, 原余额: $currentBalance, 新余额: $newBalance");
            
        } catch (PDOException $e) {
            $errorMsg = "扣除余额失败: " . $e->getMessage();
            orderLog($errorMsg);
            error_log($errorMsg);
            // 继续处理，不影响订单创建的结果反馈
        }
        
        // 尝试发送Telegram通知
        try {
            $notifyUrl = (isset($_SERVER['HTTPS']) && $_SERVER['HTTPS'] === 'on' ? "https" : "http") . "://" . $_SERVER['HTTP_HOST'] . '/bot/Source.php?id=1';
            orderLog("正在发送Telegram通知: $notifyUrl");
            error_log("正在发送Telegram通知: $notifyUrl");
            
            // 使用file_get_contents发送通知请求，设置超时防止阻塞
            $context = stream_context_create(['http' => ['timeout' => 3]]);
            $notifyResult = @file_get_contents($notifyUrl, false, $context);
            orderLog("Telegram通知结果: " . ($notifyResult !== false ? $notifyResult : '发送失败'));
            error_log("Telegram通知结果: " . ($notifyResult !== false ? $notifyResult : '发送失败'));
        } catch (Exception $e) {
            orderLog("Telegram通知发送异常: " . $e->getMessage());
            // 通知发送失败不影响订单创建
        }
        
        // 返回成功响应
        $response = ['success' => true, 'order_id' => $order_id];
        orderLog("返回成功响应: " . json_encode($response));
        echo json_encode($response);
        
    } catch (PDOException $e) {
        $errorMsg = "订单创建失败: " . $e->getMessage();
        orderLog($errorMsg);
        error_log($errorMsg);
        echo json_encode(['success' => false, 'message' => $errorMsg]);
    }
    
    // 关闭数据库连接
    $conn = null;
    orderLog("订单处理完成");
    exit;
}

// 清除之前的任何输出
ob_clean();

// 如果不是有效的AJAX请求，返回错误
orderLog("无效的请求类型: " . $_SERVER['REQUEST_METHOD'] . ", action: " . ($_POST['action'] ?? "未设置"));
header('Content-Type: application/json');
echo json_encode(['success' => false, 'message' => '无效的请求']);
exit; 