<?php
// 设置错误显示
ini_set('display_errors', 1);
error_reporting(E_ALL);

// 包含必要文件
require_once __DIR__ . '/config/database.php';
require_once __DIR__ . '/product/code/product_data.php';

echo "<h1>产品筛选测试</h1>";
echo "<p>时间: " . date('Y-m-d H:i:s') . "</p>";

// 测试1: 无筛选条件
echo "<h2>测试1: 无筛选条件查询</h2>";
$noFilterResult = getProducts(['status' => 1], 'price', 'asc', 1, 5);
echo "<p>结果数量: " . count($noFilterResult['products']) . " / " . $noFilterResult['total'] . "</p>";

// 测试2: 标签筛选 - 测试"性价比高"标签（ID=15）
echo "<h2>测试2: 标签筛选 - '性价比高'(ID=15)</h2>";
$tagFilterResult = getProducts(['tag' => 15], 'price', 'asc', 1, 5);
echo "<p>结果数量: " . count($tagFilterResult['products']) . " / " . $tagFilterResult['total'] . "</p>";
if (!empty($tagFilterResult['products'])) {
    echo "<p>第一个结果:</p>";
    echo "<ul>";
    echo "<li>ID: " . $tagFilterResult['products'][0]['id'] . "</li>";
    echo "<li>标签: " . $tagFilterResult['products'][0]['tags'] . "</li>";
    echo "</ul>";
    
    // 验证标签筛选逻辑
    $tagsArray = explode(',', $tagFilterResult['products'][0]['tags']);
    if (in_array('15', $tagsArray)) {
        echo "<p style='color:green'>√ 标签筛选正确: 产品包含标签'15'</p>";
    } else {
        echo "<p style='color:red'>× 标签筛选错误: 产品不包含标签'15'</p>";
    }
}

// 测试3: 地区筛选 - 新加坡(ID=11)
echo "<h2>测试3: 地区筛选 - 新加坡(ID=11)</h2>";
$regionFilterResult = getProducts(['region' => 11], 'price', 'asc', 1, 5);
echo "<p>结果数量: " . count($regionFilterResult['products']) . " / " . $regionFilterResult['total'] . "</p>";
if (!empty($regionFilterResult['products'])) {
    echo "<p>第一个结果:</p>";
    echo "<ul>";
    echo "<li>ID: " . $regionFilterResult['products'][0]['id'] . "</li>";
    echo "<li>地区ID: " . $regionFilterResult['products'][0]['region_id'] . "</li>";
    echo "</ul>";
    
    // 验证地区筛选逻辑
    if ($regionFilterResult['products'][0]['region_id'] == 11) {
        echo "<p style='color:green'>√ 地区筛选正确: 产品地区为'11'</p>";
    } else {
        echo "<p style='color:red'>× 地区筛选错误: 产品地区不是'11'</p>";
    }
}

// 测试4: 父地区筛选 - 测试中国(ID=1)，应该包含香港和台湾的产品
echo "<h2>测试4: 父地区筛选 - 中国(ID=1)</h2>";
$parentRegionFilterResult = getProducts(['parent_region' => 1], 'price', 'asc', 1, 5);
echo "<p>结果数量: " . count($parentRegionFilterResult['products']) . " / " . $parentRegionFilterResult['total'] . "</p>";

if (!empty($parentRegionFilterResult['products'])) {
    // 获取子地区ID
    $db = getDbConnection();
    $childRegionIds = [];
    $stmt = $db->prepare("SELECT id FROM area WHERE parent_id = ? AND status = 1");
    $stmt->execute([1]);
    while ($row = $stmt->fetch(PDO::FETCH_ASSOC)) {
        $childRegionIds[] = $row['id'];
    }
    
    echo "<p>中国的子地区IDs: " . implode(', ', $childRegionIds) . "</p>";
    
    // 检查筛选结果
    $firstResult = $parentRegionFilterResult['products'][0];
    echo "<p>第一个结果:</p>";
    echo "<ul>";
    echo "<li>ID: " . $firstResult['id'] . "</li>";
    echo "<li>地区ID: " . $firstResult['region_id'] . "</li>";
    echo "</ul>";
    
    // 验证父地区筛选逻辑
    if (in_array($firstResult['region_id'], $childRegionIds) || $firstResult['region_id'] == 1) {
        echo "<p style='color:green'>√ 父地区筛选正确: 产品地区属于中国</p>";
    } else {
        echo "<p style='color:red'>× 父地区筛选错误: 产品地区不属于中国</p>";
    }
}

// 测试5: 组合筛选 - 标签 + 地区
echo "<h2>测试5: 组合筛选 - 性价比高(ID=15) + 新加坡(ID=11)</h2>";
$combinedFilterResult = getProducts(['tag' => 15, 'region' => 11], 'price', 'asc', 1, 5);
echo "<p>结果数量: " . count($combinedFilterResult['products']) . " / " . $combinedFilterResult['total'] . "</p>";

if (!empty($combinedFilterResult['products'])) {
    $firstResult = $combinedFilterResult['products'][0];
    echo "<p>第一个结果:</p>";
    echo "<ul>";
    echo "<li>ID: " . $firstResult['id'] . "</li>";
    echo "<li>地区ID: " . $firstResult['region_id'] . "</li>";
    echo "<li>标签: " . $firstResult['tags'] . "</li>";
    echo "</ul>";
    
    // 验证组合筛选逻辑
    $tagsArray = explode(',', $firstResult['tags']);
    $isCorrect = $firstResult['region_id'] == 11 && in_array('15', $tagsArray);
    
    if ($isCorrect) {
        echo "<p style='color:green'>√ 组合筛选正确: 产品同时符合地区和标签条件</p>";
    } else {
        echo "<p style='color:red'>× 组合筛选错误: 产品不符合筛选条件</p>";
    }
}

// 测试6: 价格筛选
echo "<h2>测试6: 价格筛选 - 50-100</h2>";
$priceFilterResult = getProducts(['min_price' => 50, 'max_price' => 100], 'price', 'asc', 1, 5);
echo "<p>结果数量: " . count($priceFilterResult['products']) . " / " . $priceFilterResult['total'] . "</p>";

if (!empty($priceFilterResult['products'])) {
    $firstResult = $priceFilterResult['products'][0];
    echo "<p>第一个结果:</p>";
    echo "<ul>";
    echo "<li>ID: " . $firstResult['id'] . "</li>";
    echo "<li>价格: " . $firstResult['price'] . "</li>";
    echo "</ul>";
    
    // 验证价格筛选逻辑
    if ($firstResult['price'] >= 50 && $firstResult['price'] <= 100) {
        echo "<p style='color:green'>√ 价格筛选正确: 产品价格在50-100范围内</p>";
    } else {
        echo "<p style='color:red'>× 价格筛选错误: 产品价格不在50-100范围内</p>";
    }
} 