<?php
// 初始化产品页面所需的变量和数据

// 确保包含product_data.php
require_once __DIR__ . '/product_data.php';

// 获取产品数据
$regionData = getRegionData();
$parentRegions = $regionData['parentRegions'];
$childRegionsByParent = $regionData['childRegionsByParent'];

$tagData = getTagData();
$parentTags = $tagData['parentTags'];
$childTagsByParent = $tagData['childTagsByParent'];

$priceRanges = getPriceRangeData();
$lineData = getLineData();

// 处理筛选参数
$selectedTag = isset($_GET['tag']) ? (int)$_GET['tag'] : 0;
$selectedRegion = isset($_GET['region']) ? (int)$_GET['region'] : 0;
$selectedParent = isset($_GET['parent_region']) ? (int)$_GET['parent_region'] : (count($parentRegions) > 0 ? $parentRegions[0]['id'] : 0);

// 用于显示的父地区（如果没有选中地区，则显示选中的父地区）
$selectedParentForDisplay = $selectedParent;

// 如果选择了具体地区，找出该地区所属的父地区
if ($selectedRegion) {
    foreach ($childRegionsByParent as $parentId => $children) {
        foreach ($children as $child) {
            if ($child['id'] == $selectedRegion) {
                $selectedParentForDisplay = $parentId;
                break 2;
            }
        }
    }
}

// 处理价格筛选
$selectedMinPrice = isset($_GET['min_price']) ? $_GET['min_price'] : null;
$selectedMaxPrice = isset($_GET['max_price']) ? $_GET['max_price'] : null;

// 处理排序参数 - 默认按价格从低到高排序
$sortBy = isset($_GET['sort']) ? $_GET['sort'] : 'price';
$sortOrder = isset($_GET['order']) ? $_GET['order'] : 'asc';

// 处理分页
$currentPage = isset($_GET['page']) ? (int)$_GET['page'] : 1;
$limit = 18; // 每页显示18个产品，提高每页显示数量

// 设置排序图标（向上箭头为降序，向下箭头为升序）
$priceIcon = $sortBy == 'price' ? ($sortOrder == 'desc' ? 'arrow_upward' : 'arrow_downward') : 'unfold_more';
$createdIcon = $sortBy == 'created' ? ($sortOrder == 'desc' ? 'arrow_upward' : 'arrow_downward') : 'unfold_more';

// 准备筛选参数
$filters = [];
if ($selectedTag) {
    $filters['tag'] = $selectedTag;
}
if ($selectedRegion) {
    $filters['region'] = $selectedRegion;
} elseif ($selectedParent) {
    $filters['parent_region'] = $selectedParent;
}
if ($selectedMinPrice !== null) {
    $filters['min_price'] = $selectedMinPrice;
}
if ($selectedMaxPrice !== null) {
    $filters['max_price'] = $selectedMaxPrice;
}

// 确保数据库连接存在
global $db;
if (!isset($db) || !$db) {
    $db = getDbConnection();
}

// 获取产品数据
try {
    // 如果筛选条件为空且非调试模式，添加一个默认筛选条件显示所有产品
    if (empty($filters) || (isset($filters['parent_region']) && $filters['parent_region'] == 0)) {
        // 不添加筛选条件，查询所有状态为1的产品
        // 这确保即使用户没有选择任何筛选条件也能看到产品
        $filters = ['status' => 1];
    }
    
    // 调用产品查询函数
    $productsData = getProducts($filters, $sortBy, $sortOrder, $currentPage, $limit);
    $products = isset($productsData['products']) ? $productsData['products'] : []; // 获取产品列表
    $totalProducts = isset($productsData['total']) ? $productsData['total'] : 0; // 获取总数
    $totalPages = ceil($totalProducts / $limit);

    if (function_exists('logDebug')) {
        @logDebug("product_init.php - 产品查询成功: 总记录数=$totalProducts, 实际获取记录数=" . count($products));
    }
    
    // 如果没有找到产品，尝试不带筛选条件再查询一次
    if (empty($products) && !empty($filters) && !isset($filters['status'])) {
        if (function_exists('logDebug')) {
            @logDebug("product_init.php - 没有找到符合条件的产品，尝试查询所有产品");
        }
        $fallbackProductsData = getProducts(['status' => 1], $sortBy, $sortOrder, $currentPage, $limit);
        $products = isset($fallbackProductsData['products']) ? $fallbackProductsData['products'] : [];
        $totalProducts = isset($fallbackProductsData['total']) ? $fallbackProductsData['total'] : 0;
        $totalPages = ceil($totalProducts / $limit);
        
        // 添加一个提示信息，告诉用户已显示所有产品
        $showAllProducts = true;
    } else {
        $showAllProducts = false;
    }
} catch (Exception $e) {
    if (function_exists('logDebug')) {
        @logDebug("product_init.php - 产品查询失败: " . $e->getMessage());
    }
    $products = [];
    $totalProducts = 0;
    $totalPages = 0;
}

// 准备地区名称数组，用于显示
$areaNames = [];
foreach ($parentRegions as $parent) {
    $areaNames[$parent['id']] = $parent['name']; // 添加父级地区名称
    if (isset($childRegionsByParent[$parent['id']])) {
        foreach ($childRegionsByParent[$parent['id']] as $child) {
            $areaNames[$child['id']] = $child['name'];
        }
    }
}

// 所有地区数据，包含父地区和子地区
$allRegions = [];
foreach ($parentRegions as $parent) {
    $allRegions[$parent['id']] = $parent;
    if (isset($childRegionsByParent[$parent['id']])) {
        foreach ($childRegionsByParent[$parent['id']] as $child) {
            $allRegions[$child['id']] = $child;
        }
    }
}

// 移除重复的getRegionData和getTagData函数，保留product_data.php中的实现 
