<?php
if (!defined('ROOT_PATH')) {
    define('ROOT_PATH', dirname(dirname(__DIR__)));
}
include ROOT_PATH . '/public/config.php';
define('INCLUDED_FROM_VIEW', true);
require_once ROOT_PATH . '/code/product_detail_logic.php';
$debug = [];
$debug['request_uri'] = $_SERVER['REQUEST_URI'];
$debug['get_params'] = $_GET;
$product_id = isset($_GET['id']) ? intval($_GET['id']) : 0;
if ($product_id == 0) {
    $patterns = [
        '/\\/product\/(\d+)\.html/',
        '/\/product\/(\d+)\.html/',
        '/\/(\d+)\.html/'
    ];
    foreach ($patterns as $index => $pattern) {
        $debug['pattern_'.$index] = $pattern;
        if (preg_match($pattern, $_SERVER['REQUEST_URI'], $matches)) {
            $product_id = intval($matches[1]);
            $debug['matches_'.$index] = $matches;
            break;
        }
    }
}
$debug['final_product_id'] = $product_id;
if ($product_id == 0) {
    $showError = true;
    $errorMessage = "该机器不存在，请联系在线客服咨询";
    if (defined('DEBUG_MODE') && DEBUG_MODE) {
        $errorMessage .= "<br>调试信息: " . json_encode($debug, JSON_UNESCAPED_UNICODE);
    }
} else {
    $result = processProductDetail($product_id);
    if ($result['success']) {
        $showError = false;
        $product = $result['product'];
        $productCode = $result['productCode'];
        $locationText = $result['locationText'];
        $lineName = $result['lineName'];
        $tags = $result['tags'];
        $prices = $result['prices'];
        $regionData = $result['regionData'];
        $networkTestData = $result['networkTestData'];
        $ispData = $result['ispData'];
        $features = $result['features'];
        $faqData = $result['faqData'];
        $reviews = $result['reviews'];
        $recommendedProducts = $result['recommendedProducts'];
        $seoMetadata = $result['seoMetadata'];
        $defaultDescription = $result['defaultDescription'];
        $serviceGuarantees = $result['serviceGuarantees'];
        extract($regionData);
    } else {
        $showError = true;
        $errorMessage = "该机器不存在，请联系在线客服咨询";
        if (defined('DEBUG_MODE') && DEBUG_MODE) {
            $errorMessage .= "<br>调试信息: " . json_encode($debug, JSON_UNESCAPED_UNICODE);
        }
    }
}

/**
 * 显示地区信息，格式为：地区/国家（如果国家不是中国）
 * 
 * @param array $product 产品数据
 * @param array $regionData 地区数据
 * @param string $locationText 默认位置文本
 * @param bool $appendProductInfo 是否添加产品内存信息
 * @return string 格式化后的地区信息
 */
function displayRegionInfo($product, $regionData, $locationText, $appendProductInfo = false) {
    $output = '';
    
    if (isset($product['region_id']) && isset($regionData['areaNames'][$product['region_id']])) {
        $regionName = $regionData['areaNames'][$product['region_id']];
        $countryName = '';
        
        // 查找该地区的父级地区(国家)
        foreach ($regionData['allRegions'] as $region) {
            if ($region['id'] == $product['region_id'] && !empty($region['parent_id'])) {
                // 找到父级地区(国家)名称
                foreach ($regionData['parentRegions'] as $parent) {
                    if ($parent['id'] == $region['parent_id']) {
                        $countryName = $parent['name'];
                        break;
                    }
                }
                break;
            }
        }
        
        // 显示格式：地区/国家
        $output .= $regionName;
        if (!empty($countryName) && $countryName != '中国') {
            $output .= '/' . $countryName;
        }
    } else {
        $output .= $locationText;
    }
    
    // 添加产品信息（如果需要）
    if ($appendProductInfo && isset($product['memory'])) {
        $output .= "高速服务器 - " . htmlspecialchars($product['memory']) . "内存";
    }
    
    return $output;
}

/**
 * 格式化常见问题回答内容
 * 
 * @param string $answer 问题的回答内容
 * @return string 格式化后的回答内容
 */
function formatFaqAnswer($answer) {
    // 处理换行符为HTML段落
    $answer = nl2br($answer);
    
    // 可以在这里添加更多格式化逻辑，例如：
    // - 链接识别和转换
    // - 关键词突出显示
    // - 内容过滤或转义等
    
    return $answer;
}
?>
