<?php
// 设置错误显示
ini_set('display_errors', 1);
error_reporting(E_ALL);

// 包含必要文件
require_once __DIR__ . '/../config/config.php';
require_once __DIR__ . '/../config/database.php';

echo "<h1>产品调试页面</h1>";
echo "<p>时间: " . date('Y-m-d H:i:s') . "</p>";

// 检查数据库连接
try {
    $db = getDbConnection();
    echo "<p style='color:green'>数据库连接成功</p>";
    
    // 检查获取产品数据的函数
    if (!function_exists('getProducts')) {
        echo "<p style='color:red'>getProducts函数不存在，正在包含product_data.php</p>";
        require_once __DIR__ . '/../code/product_data.php';
    }
    
    // 测试查询新加坡地区的产品
    $regionId = 11; // 新加坡
    echo "<p>尝试查询新加坡(region_id=$regionId)的产品数据...</p>";
    
    // 查询该地区的产品总数
    $stmt = $db->prepare("SELECT COUNT(*) FROM products WHERE region_id = ?");
    $stmt->execute([$regionId]);
    $count = $stmt->fetchColumn();
    echo "<p>数据库中新加坡地区的产品总数: $count</p>";
    
    // 定义筛选条件
    $filters = ['region' => $regionId];
    $sort = 'price';
    $order = 'asc';
    $page = 1;
    $limit = 10;
    
    echo "<p>调用getProducts函数查询数据...</p>";
    $result = getProducts($filters, $sort, $order, $page, $limit);
    
    // 显示筛选结果
    echo "<p>getProducts返回结果：</p>";
    echo "<ul>";
    echo "<li>产品数量: " . count($result['products']) . "</li>";
    echo "<li>总记录数: " . $result['total'] . "</li>";
    echo "<li>页码: " . $result['page'] . "</li>";
    echo "<li>每页数量: " . $result['limit'] . "</li>";
    echo "</ul>";
    
    // 显示产品列表
    if (!empty($result['products'])) {
        echo "<h2>产品列表示例(前5条)：</h2>";
        echo "<table border='1' cellpadding='5'>";
        echo "<tr><th>ID</th><th>CPU</th><th>内存</th><th>硬盘</th><th>价格</th><th>地区ID</th></tr>";
        
        $count = 0;
        foreach ($result['products'] as $product) {
            if ($count < 5) {
                echo "<tr>";
                echo "<td>" . $product['id'] . "</td>";
                echo "<td>" . $product['cpu'] . "</td>";
                echo "<td>" . $product['memory'] . "</td>";
                echo "<td>" . $product['disk'] . "</td>";
                echo "<td>" . $product['price'] . "</td>";
                echo "<td>" . $product['region_id'] . "</td>";
                echo "</tr>";
                $count++;
            } else {
                break;
            }
        }
        
        echo "</table>";
    } else {
        echo "<p style='color:red'>没有找到符合条件的产品</p>";
    }
    
    // 测试区域数据获取
    if (function_exists('getRegionData')) {
        echo "<h2>地区数据测试：</h2>";
        $regionData = getRegionData();
        echo "<p>父级地区数量: " . count($regionData['parentRegions']) . "</p>";
        echo "<p>子地区分组数量: " . count($regionData['childRegionsByParent']) . "</p>";
    } else {
        echo "<p style='color:red'>getRegionData函数不存在</p>";
    }
    
} catch (Exception $e) {
    echo "<p style='color:red'>错误: " . $e->getMessage() . "</p>";
}
?> 