<?php
// 设置错误报告级别
ini_set('display_errors', 1);
error_reporting(E_ALL);

// 输出基本信息
echo "<h1>产品数据诊断</h1>";
echo "<p>时间: " . date('Y-m-d H:i:s') . "</p>";

// 包含数据库配置
require_once __DIR__ . '/../config/database.php';
echo "<p>数据库配置已加载</p>";

// 测试数据库连接
try {
    $db = getDbConnection();
    echo "<p>数据库连接成功！</p>";
    
    // 显示数据库信息
    $dbInfo = $db->getAttribute(PDO::ATTR_SERVER_INFO);
    echo "<p>数据库信息: " . ($dbInfo ? $dbInfo : "无法获取") . "</p>";
    
    // 测试查询产品总数
    $stmt = $db->query("SELECT COUNT(*) FROM products WHERE status = 1");
    $totalProducts = $stmt->fetchColumn();
    echo "<p>启用状态的产品总数: $totalProducts</p>";
    
    // 获取10个样本产品
    $stmt = $db->query("SELECT id, cpu, memory, disk, price, region_id, tags FROM products WHERE status = 1 ORDER BY id DESC LIMIT 10");
    $sampleProducts = $stmt->fetchAll(PDO::FETCH_ASSOC);
    
    echo "<h2>最新10个产品样本:</h2>";
    echo "<table border='1'>";
    echo "<tr><th>ID</th><th>CPU</th><th>内存</th><th>硬盘</th><th>价格</th><th>地区ID</th><th>标签</th></tr>";
    
    foreach ($sampleProducts as $product) {
        echo "<tr>";
        echo "<td>{$product['id']}</td>";
        echo "<td>{$product['cpu']}</td>";
        echo "<td>{$product['memory']}</td>";
        echo "<td>{$product['disk']}</td>";
        echo "<td>{$product['price']}</td>";
        echo "<td>{$product['region_id']}</td>";
        echo "<td>{$product['tags']}</td>";
        echo "</tr>";
    }
    
    echo "</table>";
    
    // 检查标签系统
    echo "<h2>标签系统检查:</h2>";
    
    $stmt = $db->query("SELECT DISTINCT tags FROM products WHERE tags IS NOT NULL LIMIT 10");
    $tags = $stmt->fetchAll(PDO::FETCH_COLUMN);
    
    echo "<p>标签样本: ";
    foreach ($tags as $tag) {
        echo "$tag, ";
    }
    echo "</p>";
    
    // 检查地区系统
    echo "<h2>地区系统检查:</h2>";
    
    $stmt = $db->query("SELECT DISTINCT region_id FROM products WHERE region_id IS NOT NULL LIMIT 10");
    $regions = $stmt->fetchAll(PDO::FETCH_COLUMN);
    
    echo "<p>地区ID样本: ";
    foreach ($regions as $region) {
        echo "$region, ";
    }
    echo "</p>";
    
    // 模拟产品筛选
    echo "<h2>模拟筛选测试:</h2>";
    
    // 按价格从低到高排序
    $stmt = $db->query("SELECT id, cpu, price FROM products WHERE status = 1 ORDER BY price ASC LIMIT 5");
    $priceSortedProducts = $stmt->fetchAll(PDO::FETCH_ASSOC);
    
    echo "<p>价格从低到高的前5个产品:</p>";
    echo "<ul>";
    foreach ($priceSortedProducts as $product) {
        echo "<li>ID: {$product['id']}, CPU: {$product['cpu']}, 价格: {$product['price']}</li>";
    }
    echo "</ul>";
    
} catch (PDOException $e) {
    echo "<p style='color:red'>数据库连接或查询错误: " . $e->getMessage() . "</p>";
}
?> 