<?php
// 设置错误显示
ini_set('display_errors', 1);
error_reporting(E_ALL);

// 包含必要文件
require_once __DIR__ . '/config/database.php';
require_once __DIR__ . '/product/code/product_data.php';
require_once __DIR__ . '/product/code/product_init.php';

echo "<h1>产品页面测试</h1>";
echo "<p>时间: " . date('Y-m-d H:i:s') . "</p>";

// 检查变量初始化
echo "<h2>变量初始化检查</h2>";
echo "<ul>";
echo "<li>总产品数: " . $totalProducts . "</li>";
echo "<li>当前页: " . $currentPage . "</li>";
echo "<li>总页数: " . $totalPages . "</li>";
echo "<li>产品数组类型: " . gettype($products) . "</li>";
echo "<li>产品数组数量: " . (is_array($products) ? count($products) : '非数组') . "</li>";
echo "</ul>";

// 检查筛选条件
echo "<h2>筛选条件检查</h2>";
echo "<pre>" . print_r($filters, true) . "</pre>";

// 测试显示产品
echo "<h2>产品卡片显示测试</h2>";

if (empty($products)) {
    echo "<p style='color:red'>没有找到产品数据</p>";
    
    // 尝试强制查询所有产品
    echo "<p>尝试直接查询所有产品...</p>";
    $allProducts = getProducts(['status' => 1], 'price', 'asc', 1, 10);
    
    if (!empty($allProducts['products'])) {
        echo "<p style='color:green'>成功获取 " . count($allProducts['products']) . " 个产品</p>";
        $products = $allProducts['products'];
    } else {
        echo "<p style='color:red'>直接查询也无法获取产品</p>";
    }
}

// 显示产品卡片示例
if (!empty($products)) {
    echo "<p style='color:green'>找到 " . count($products) . " 个产品</p>";
    echo "<div style='display:flex; flex-wrap:wrap; gap:20px;'>";
    
    foreach (array_slice($products, 0, 3) as $product) {
        echo "<div style='border:1px solid #ddd; border-radius:5px; padding:15px; width:300px;'>";
        echo "<h3>ID: " . $product['id'] . " - " . ($product['title'] ?? '无标题') . "</h3>";
        echo "<div><strong>地区:</strong> " . $product['region_id'] . "</div>";
        echo "<div><strong>CPU:</strong> " . ($product['cpu'] ?? 'N/A') . "</div>";
        echo "<div><strong>内存:</strong> " . ($product['memory'] ?? 'N/A') . "</div>";
        echo "<div><strong>硬盘:</strong> " . ($product['disk'] ?? 'N/A') . "</div>";
        echo "<div><strong>价格:</strong> " . ($product['price'] ?? 'N/A') . " 元/月</div>";
        echo "<div><strong>标签:</strong> " . ($product['tags'] ?? 'N/A') . "</div>";
        echo "</div>";
    }
    
    echo "</div>";
} else {
    echo "<p style='color:red'>仍然无法获取产品数据</p>";
}

// 检查地区数据
echo "<h2>地区数据检查</h2>";
echo "<ul>";
echo "<li>父地区数量: " . (isset($parentRegions) ? count($parentRegions) : '未初始化') . "</li>";
echo "<li>子地区分组数量: " . (isset($childRegionsByParent) ? count($childRegionsByParent) : '未初始化') . "</li>";
echo "</ul>";

// 检查标签数据
echo "<h2>标签数据检查</h2>";
echo "<ul>";
echo "<li>父标签数量: " . (isset($parentTags) ? count($parentTags) : '未初始化') . "</li>";
echo "<li>子标签分组数量: " . (isset($childTagsByParent) ? count($childTagsByParent) : '未初始化') . "</li>";
echo "</ul>";

// 检查数据库连接
echo "<h2>数据库连接检查</h2>";
global $db;
if ($db) {
    echo "<p style='color:green'>数据库连接正常</p>";
    
    // 执行直接查询
    try {
        $count = $db->query("SELECT COUNT(*) FROM products WHERE status = 1")->fetchColumn();
        echo "<p>数据库中的活跃产品总数: " . $count . "</p>";
    } catch (Exception $e) {
        echo "<p style='color:red'>查询失败: " . $e->getMessage() . "</p>";
    }
} else {
    echo "<p style='color:red'>数据库连接失败</p>";
} 