<?php
// 设置错误显示
ini_set('display_errors', 1);
error_reporting(E_ALL);

// 包含必要文件
require_once __DIR__ . '/config/database.php';
// 只包含product_init.php，因为它已经包含了product_data.php
require_once __DIR__ . '/product/code/product_init.php';

echo "<h1>产品查询测试</h1>";
echo "<p>时间: " . date('Y-m-d H:i:s') . "</p>";

// 默认条件 - 不进行筛选
$filters = ['status' => 1]; // 只查询激活的产品
$sort = 'recommended';
$order = 'asc';
$page = 1;
$limit = 10;

echo "<h2>测试1: 无筛选查询所有产品</h2>";
try {
    $productsData = getProducts($filters, $sort, $order, $page, $limit);
    
    echo "<p>查询结果: ";
    echo "总数: " . $productsData['total'] . ", ";
    echo "当前页结果数: " . count($productsData['products']);
    echo "</p>";
    
    if (!empty($productsData['products'])) {
        echo "<table border='1'>";
        echo "<tr><th>ID</th><th>标题</th><th>CPU</th><th>内存</th><th>价格</th><th>地区ID</th><th>标签</th></tr>";
        
        foreach ($productsData['products'] as $product) {
            echo "<tr>";
            echo "<td>" . $product['id'] . "</td>";
            echo "<td>" . ($product['title'] ?? '无标题') . "</td>";
            echo "<td>" . ($product['cpu'] ?? 'N/A') . "</td>";
            echo "<td>" . ($product['memory'] ?? 'N/A') . "</td>";
            echo "<td>" . ($product['price'] ?? 'N/A') . "</td>";
            echo "<td>" . ($product['region_id'] ?? 'N/A') . "</td>";
            echo "<td>" . ($product['tags'] ?? 'N/A') . "</td>";
            echo "</tr>";
        }
        
        echo "</table>";
    } else {
        echo "<p>没有找到产品</p>";
    }
} catch (Exception $e) {
    echo "<p>错误: " . $e->getMessage() . "</p>";
}

// 测试2: 按地区筛选 - 新加坡 (region_id=11)
echo "<h2>测试2: 筛选新加坡地区产品</h2>";
try {
    $sgFilters = ['region' => 11]; // 新加坡地区ID
    $productsData = getProducts($sgFilters, $sort, $order, $page, $limit);
    
    echo "<p>查询结果: ";
    echo "总数: " . $productsData['total'] . ", ";
    echo "当前页结果数: " . count($productsData['products']);
    echo "</p>";
    
    if (!empty($productsData['products'])) {
        echo "<table border='1'>";
        echo "<tr><th>ID</th><th>标题</th><th>CPU</th><th>内存</th><th>价格</th><th>地区ID</th><th>标签</th></tr>";
        
        foreach ($productsData['products'] as $product) {
            echo "<tr>";
            echo "<td>" . $product['id'] . "</td>";
            echo "<td>" . ($product['title'] ?? '无标题') . "</td>";
            echo "<td>" . ($product['cpu'] ?? 'N/A') . "</td>";
            echo "<td>" . ($product['memory'] ?? 'N/A') . "</td>";
            echo "<td>" . ($product['price'] ?? 'N/A') . "</td>";
            echo "<td>" . ($product['region_id'] ?? 'N/A') . "</td>";
            echo "<td>" . ($product['tags'] ?? 'N/A') . "</td>";
            echo "</tr>";
        }
        
        echo "</table>";
    } else {
        echo "<p>没有找到产品</p>";
    }
} catch (Exception $e) {
    echo "<p>错误: " . $e->getMessage() . "</p>";
}

// 测试3: 按标签筛选 - 标签ID=15 (性价比高)
echo "<h2>测试3: 筛选标签为'性价比高'的产品</h2>";
try {
    $tagFilters = ['tag' => 15]; // 性价比高的标签ID
    $productsData = getProducts($tagFilters, $sort, $order, $page, $limit);
    
    echo "<p>查询结果: ";
    echo "总数: " . $productsData['total'] . ", ";
    echo "当前页结果数: " . count($productsData['products']);
    echo "</p>";
    
    if (!empty($productsData['products'])) {
        echo "<table border='1'>";
        echo "<tr><th>ID</th><th>标题</th><th>CPU</th><th>内存</th><th>价格</th><th>地区ID</th><th>标签</th></tr>";
        
        foreach ($productsData['products'] as $product) {
            echo "<tr>";
            echo "<td>" . $product['id'] . "</td>";
            echo "<td>" . ($product['title'] ?? '无标题') . "</td>";
            echo "<td>" . ($product['cpu'] ?? 'N/A') . "</td>";
            echo "<td>" . ($product['memory'] ?? 'N/A') . "</td>";
            echo "<td>" . ($product['price'] ?? 'N/A') . "</td>";
            echo "<td>" . ($product['region_id'] ?? 'N/A') . "</td>";
            echo "<td>" . ($product['tags'] ?? 'N/A') . "</td>";
            echo "</tr>";
        }
        
        echo "</table>";
    } else {
        echo "<p>没有找到产品</p>";
    }
} catch (Exception $e) {
    echo "<p>错误: " . $e->getMessage() . "</p>";
} 