<?php
/**
 * 测试查询含有特定标签的产品
 */

// 引入数据库配置
require_once 'config/database.php';

echo "=== 产品标签测试查询 ===\n\n";

$db = getDbConnection();

// 先查询products表结构
echo "查询products表结构：\n";
$tableQuery = "DESCRIBE products";
try {
    $tableStmt = $db->query($tableQuery);
    $tableFields = $tableStmt->fetchAll(PDO::FETCH_ASSOC);
    echo "字段列表：\n";
    foreach ($tableFields as $field) {
        echo $field['Field'] . " (" . $field['Type'] . ")\n";
    }
} catch (PDOException $e) {
    echo "无法获取表结构: " . $e->getMessage() . "\n";
}
echo "\n";

// 1. 先查询tags表中的数据
echo "查询标签表数据：\n";
$tagsQuery = "SELECT * FROM tags WHERE id IN (19, 23)";
$tagsStmt = $db->query($tagsQuery);
$tags = $tagsStmt->fetchAll(PDO::FETCH_ASSOC);

echo "标签信息：\n";
foreach ($tags as $tag) {
    echo "ID: {$tag['id']}, 名称: {$tag['name']}\n";
}
echo "\n";

// 2. 查询包含这两个标签的产品 - 使用LIKE
echo "使用LIKE查询包含标签19和23的产品：\n";
$likeQuery = "SELECT id, tags FROM products 
              WHERE tags LIKE '%19%' AND tags LIKE '%23%' AND status = 1";
$likeStmt = $db->query($likeQuery);
$likeProducts = $likeStmt->fetchAll(PDO::FETCH_ASSOC);

echo "找到 " . count($likeProducts) . " 条记录\n";
foreach ($likeProducts as $product) {
    echo "ID: {$product['id']}, 标签: {$product['tags']}\n";
}
echo "\n";

// 3. 手动分割标签查询
echo "使用手动分割查询包含标签19和23的产品：\n";
$manualQuery = "SELECT id, tags FROM products WHERE status = 1";
$manualStmt = $db->query($manualQuery);
$allProducts = $manualStmt->fetchAll(PDO::FETCH_ASSOC);
$matchingProducts = [];

foreach ($allProducts as $product) {
    if (empty($product['tags'])) continue;
    
    $tagArray = explode(',', $product['tags']);
    if (in_array('19', $tagArray) && in_array('23', $tagArray)) {
        $matchingProducts[] = $product;
    }
}

echo "找到 " . count($matchingProducts) . " 条记录\n";
foreach ($matchingProducts as $product) {
    echo "ID: {$product['id']}, 标签: {$product['tags']}\n";
}
echo "\n";

// 4. 查询所有产品的标签格式
echo "检查前10条产品的标签格式：\n";
$formatQuery = "SELECT id, tags FROM products WHERE status = 1 LIMIT 10";
$formatStmt = $db->query($formatQuery);
$formatProducts = $formatStmt->fetchAll(PDO::FETCH_ASSOC);

foreach ($formatProducts as $product) {
    echo "ID: {$product['id']}, 标签: {$product['tags']}\n";
}
echo "\n";

// 5. 查看是否有产品只包含数字19和23（不是字符串）
echo "检查是否有产品包含数字形式的标签19和23：\n";
$numericQuery = "SELECT id, tags FROM products 
                 WHERE (tags LIKE '%,19,%' OR tags LIKE '19,%' OR tags LIKE '%,19' OR tags = '19')
                 AND (tags LIKE '%,23,%' OR tags LIKE '23,%' OR tags LIKE '%,23' OR tags = '23')
                 AND status = 1";
$numericStmt = $db->query($numericQuery);
$numericProducts = $numericStmt->fetchAll(PDO::FETCH_ASSOC);

echo "找到 " . count($numericProducts) . " 条记录\n";
foreach ($numericProducts as $product) {
    echo "ID: {$product['id']}, 标签: {$product['tags']}\n";
} 