<?php
session_start();
include_once __DIR__ . '/../public/config.php';
require_once __DIR__ . '/../config/config.php';
require_once __DIR__ . '/../config/database.php';
require_once __DIR__ . '/code/auth.php';

// 确保用户已登录
if (!isLoggedIn()) {
    header('Location: /user/login.php?redirect=' . urlencode($_SERVER['REQUEST_URI']));
    exit;
}

$userId = getCurrentUserId();
$balance = calculateUserBalance($userId);

// 处理表单提交
$successMessage = '';
$errorMessage = '';

if ($_SERVER['REQUEST_METHOD'] === 'POST' && isset($_POST['submit_trial'])) {
    $productId = isset($_POST['product_id']) ? intval($_POST['product_id']) : 0;
    $productName = isset($_POST['product_name']) ? trim($_POST['product_name']) : '';
    $price = isset($_POST['price']) ? floatval($_POST['price']) : 0;
    $period = isset($_POST['period']) ? trim($_POST['period']) : 'monthly';
    $remarks = isset($_POST['remarks']) ? trim($_POST['remarks']) : '';
    
    if ($productId > 0 && !empty($productName)) {
        try {
            // 连接数据库
            $dsn = "mysql:host=" . DB_HOST . ";dbname=" . DB_NAME . ";charset=" . DB_CHARSET;
            $options = [
                PDO::ATTR_ERRMODE => PDO::ERRMODE_EXCEPTION,
                PDO::ATTR_DEFAULT_FETCH_MODE => PDO::FETCH_ASSOC,
                PDO::ATTR_EMULATE_PREPARES => false,
            ];
            
            $conn = new PDO($dsn, DB_USER, DB_PASSWORD, $options);
            
            // 插入试用申请记录
            $sql = "INSERT INTO trial_applications (member_id, product_id, product_name, price, period, remarks, status, created_at) 
                    VALUES (:member_id, :product_id, :product_name, :price, :period, :remarks, 'pending', NOW())";
            
            $stmt = $conn->prepare($sql);
            $stmt->bindParam(':member_id', $userId, PDO::PARAM_INT);
            $stmt->bindParam(':product_id', $productId, PDO::PARAM_INT);
            $stmt->bindParam(':product_name', $productName, PDO::PARAM_STR);
            $stmt->bindParam(':price', $price, PDO::PARAM_STR);
            $stmt->bindParam(':period', $period, PDO::PARAM_STR);
            $stmt->bindParam(':remarks', $remarks, PDO::PARAM_STR);
            
            $stmt->execute();
            
            // 发送Telegram通知
            $notifyUrl = (isset($_SERVER['HTTPS']) && $_SERVER['HTTPS'] === 'on' ? "https" : "http") . "://" . $_SERVER['HTTP_HOST'] . '/bot/Source.php?id=2&trial=1';
            $context = stream_context_create(['http' => ['timeout' => 3]]);
            @file_get_contents($notifyUrl, false, $context);
            
            $successMessage = "试用申请已提交成功！客服将尽快与您联系。";
        } catch (PDOException $e) {
            $errorMessage = "申请提交失败: " . $e->getMessage();
            error_log("Trial申请失败: " . $e->getMessage());
        }
    } else {
        $errorMessage = "产品信息不完整，请返回购物车重新操作。";
    }
}

// 从请求参数获取产品信息
$productId = isset($_GET['product_id']) ? intval($_GET['product_id']) : 0;
$productName = isset($_GET['product_name']) ? trim($_GET['product_name']) : '';
$price = isset($_GET['price']) ? floatval($_GET['price']) : 0;
$period = isset($_GET['period']) ? trim($_GET['period']) : 'monthly';

// 获取产品信息（如果有产品ID）
$productDetails = [];
if ($productId > 0) {
    try {
        $dsn = "mysql:host=" . DB_HOST . ";dbname=" . DB_NAME . ";charset=" . DB_CHARSET;
        $conn = new PDO($dsn, DB_USER, DB_PASSWORD);
        $conn->setAttribute(PDO::ATTR_ERRMODE, PDO::ERRMODE_EXCEPTION);
        
        $stmt = $conn->prepare("SELECT * FROM products WHERE id = :id");
        $stmt->bindParam(':id', $productId, PDO::PARAM_INT);
        $stmt->execute();
        
        $productDetails = $stmt->fetch(PDO::FETCH_ASSOC);
        
        if ($productDetails && empty($productName)) {
            $productName = $productDetails['name'] ?? '';
        }
    } catch (PDOException $e) {
        error_log("获取产品信息失败: " . $e->getMessage());
    }
}
?>
<!DOCTYPE html>
<html lang="zh">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>申请产品试用 - 先试用后转正</title>
    <meta name="description" content="申请产品免费试用，满意后再付款，不满意不收任何费用。">
    <link href="https://fonts.googleapis.com/icon?family=Material+Icons" rel="stylesheet">
    <link href="https://unpkg.com/aos@2.3.1/dist/aos.css" rel="stylesheet">
    <link href="/public/css/style.css" rel="stylesheet">
    <link href="/user/css/user.css" rel="stylesheet">
    <link href="/public/css/breadcrumb.css" rel="stylesheet">
    <style>
        .trial-container {
            max-width: 800px;
            margin: 0 auto;
            padding: 20px;
            background: #fff;
            border-radius: 8px;
            box-shadow: 0 0 10px rgba(0, 0, 0, 0.1);
        }
        .form-row {
            margin-bottom: 20px;
        }
        .form-row label {
            display: block;
            margin-bottom: 5px;
            font-weight: bold;
        }
        .form-row input[type="text"],
        .form-row textarea,
        .form-row select {
            width: 100%;
            padding: 10px;
            border: 1px solid #ddd;
            border-radius: 4px;
        }
        .form-row textarea {
            height: 100px;
        }
        .submit-btn {
            background: #4CAF50;
            color: white;
            padding: 10px 20px;
            border: none;
            border-radius: 4px;
            cursor: pointer;
            font-size: 16px;
        }
        .submit-btn:hover {
            background: #45a049;
        }
        .message {
            padding: 10px;
            margin-bottom: 20px;
            border-radius: 4px;
        }
        .success {
            background-color: #d4edda;
            border: 1px solid #c3e6cb;
            color: #155724;
        }
        .error {
            background-color: #f8d7da;
            border: 1px solid #f5c6cb;
            color: #721c24;
        }
        .trial-info {
            background-color: #e7f3fe;
            border: 1px solid #b6d4fe;
            color: #084298;
            padding: 15px;
            border-radius: 4px;
            margin-bottom: 20px;
        }
        .product-info {
            background-color: #f8f9fa;
            padding: 15px;
            border-radius: 4px;
            margin-bottom: 20px;
        }
        .product-info h3 {
            margin-top: 0;
        }
    </style>
</head>
<body>
    <!-- 顶部导航 -->
    <?php include '../public/header.php'; ?>
    
    <!-- Banner 区域 -->
    <?php include '../public/banner.php'; ?>
    
    <!--内容区块-->
    <div class="container">
        <div class="main">
            <!-- 面包屑导航 -->
            <div class="breadcrumb">
                <a href="/">首页</a>
                <i class="material-icons">chevron_right</i>
                <a href="/user">用户中心</a>
                <i class="material-icons">chevron_right</i>
                <span>申请产品试用</span>
            </div>
            
            <div class="trial-container">
                <h2>申请产品试用</h2>
                
                <?php if (!empty($successMessage)): ?>
                <div class="message success">
                    <?php echo $successMessage; ?>
                </div>
                <?php endif; ?>
                
                <?php if (!empty($errorMessage)): ?>
                <div class="message error">
                    <?php echo $errorMessage; ?>
                </div>
                <?php endif; ?>
                
                <div class="trial-info">
                    <h3>先试用后转正 - 满意才付款</h3>
                    <p>我们提供先试用后付款的服务，您可以先免费试用产品，如果满意再付款。不满意不收取任何费用，试用期间的服务完全免费。</p>
                    <p>试用申请提交后，客服会在24小时内与您联系，为您开通试用服务。</p>
                </div>
                
                <?php if (empty($successMessage)): ?>
                <div class="product-info">
                    <h3>产品信息</h3>
                    <?php if ($productId > 0 && !empty($productName)): ?>
                    <p><strong>产品名称：</strong> <?php echo htmlspecialchars($productName); ?></p>
                    <p><strong>价格：</strong> $<?php echo number_format($price, 2); ?></p>
                    <p><strong>付款周期：</strong> 
                        <?php 
                        $periodText = '月付';
                        switch ($period) {
                            case 'quarterly': $periodText = '季付'; break;
                            case 'half-year': $periodText = '半年付'; break;
                            case 'yearly': $periodText = '年付'; break;
                        }
                        echo $periodText;
                        ?>
                    </p>
                    <?php else: ?>
                    <p>未提供产品信息。请返回购物车选择产品。</p>
                    <p><a href="/cart.php" class="btn">返回购物车</a></p>
                    <?php endif; ?>
                </div>
                
                <form action="" method="post">
                    <input type="hidden" name="product_id" value="<?php echo $productId; ?>">
                    <input type="hidden" name="product_name" value="<?php echo htmlspecialchars($productName); ?>">
                    <input type="hidden" name="price" value="<?php echo $price; ?>">
                    <input type="hidden" name="period" value="<?php echo $period; ?>">
                    
                    <div class="form-row">
                        <label for="remarks">备注信息（可选）：</label>
                        <textarea name="remarks" id="remarks" placeholder="请填写您的特殊需求或备注信息"></textarea>
                    </div>
                    
                    <div class="form-row">
                        <button type="submit" name="submit_trial" class="submit-btn">提交试用申请</button>
                    </div>
                </form>
                <?php endif; ?>
                
                <?php if (!empty($successMessage)): ?>
                <p><a href="/user/index.php" class="btn">返回用户中心</a></p>
                <?php endif; ?>
            </div>
        </div>
    </div>
    
    <?php include '../public/footer.php'; ?>
    <?php include '../public/kf.php'; ?>
    
    <script src="/public/js/js.js"></script>
</body>
</html> 